@@ -1,4 +1,3 @@
-import stat
 import os
 
 from pytest_shutil import cmdline
@@ -10,13 +9,14 @@ def test_umask(workspace):
         f.touch()
     assert (f.stat().st_mode & 0o777) == 0o464
 
-def test_pretty_formatter():
+def test_pretty_formatter(monkeypatch):
+    monkeypatch.setenv("FORCE_COLOR", "1")
     f = cmdline.PrettyFormatter()
     f.title('A Title')
     f.hr()
     f.p('A Paragraph', 'red')
     assert f.buffer == [
-        '\x1b[1m\x1b[34m  A Title\x1b[0m', 
+        '\x1b[1m\x1b[34m  A Title\x1b[0m',
         '\x1b[1m\x1b[34m--------------------------------------------------------------------------------\x1b[0m',
         '\x1b[31mA Paragraph\x1b[0m'
         ]
@@ -32,8 +32,8 @@ def test_tempdir():
 def test_copy_files(workspace):
     d1 = workspace.workspace / 'd1'
     d2 = workspace.workspace / 'd2'
-    d1.makedirs()
-    d2.makedirs()
+    os.makedirs(d1)
+    os.makedirs(d2)
     (d1 / 'foo').touch()
     (d1 / 'bar').touch()
     cmdline.copy_files(d1, d2)
